@@ -23,15 +23,15 @@ def update_current_result(exc_info):
         current_result = slash_context.session.results.global_result
 
     exc_class = exc_info[0]
-    if issubclass(exc_class, TestFailed):
+    if issubclass(exc_class, (AssertionError, TestFailed)):
         current_result.add_failure()
     elif issubclass(exc_class, Exception) and not issubclass(exc_class, SkipTest):
         current_result.add_error()
 
 def trigger_hooks_before_debugger(_):
-    trigger_hook.exception_caught_before_debugger()
+    trigger_hook.exception_caught_before_debugger()  # pylint: disable=no-member
 def trigger_hooks_after_debugger(_):
-    trigger_hook.exception_caught_after_debugger()
+    trigger_hook.exception_caught_after_debugger()  # pylint: disable=no-member
 
 _EXCEPTION_HANDLERS = [
     update_current_result,
