@@ -59,7 +59,10 @@ class SessionLogging(object):
         super(SessionLogging, self).__init__()
         self.warnings_handler = WarnHandler(session.warnings)
         self.console_handler = ConsoleHandler(bubble=True, level=config.root.log.console_level)
-        self.session_log_path = self.test_log_path = None
+        #: contains the path for the session logs
+        self.session_log_path = None
+        #: contains the path for the current test logs
+        self.test_log_path = None
         self._set_formatting(self.console_handler)
 
     @contextmanager
@@ -125,7 +128,7 @@ class SessionLogging(object):
         symlink = self._normalize_path(symlink)
 
         if not os.path.isabs(symlink):
-            symlink = os.path.join(config.root.log.root, symlink)
+            symlink = os.path.join(self._normalize_path(config.root.log.root), symlink)
 
         try:
             ensure_containing_directory(symlink)
