@@ -10,10 +10,7 @@ import slash
 from .utils import run_tests_assert_success, run_tests_in_session, TestCase
 
 
-def test_last_session_symlinks(logs_dir, session):
-
-    files_dir = logs_dir.join("logs", "files")
-    links_dir = logs_dir.join("logs", "links")
+def test_last_session_symlinks(files_dir, links_dir, session):
 
     test_log_file = files_dir.join(
         session.id, list(session.results.iter_test_results())[-1].test_metadata.id, "log")
@@ -25,11 +22,32 @@ def test_last_session_symlinks(logs_dir, session):
     assert links_dir.join("last-test").readlink() == test_log_file
 
 
-def test_result_log_links(logs_dir, session):
+def test_last_test_not_overriden_by_stop_on_error(links_dir, populated_suite):
+    failed_test = populated_suite[4]
+    failed_test.fail()
+    results = populated_suite.run(stop_on_error=True)
+
+    for link_name in ('last-test', 'last-failed'):
+        assert links_dir.join(link_name).readlink() == results[
+            failed_test].get_log_path()
+
+
+def test_result_log_links(files_dir, session):
 
     for result in session.results.iter_test_results():
         assert result.get_log_path() is not None
-        assert result.get_log_path().startswith(str(logs_dir.join("logs", "files")))
+        assert result.get_log_path().startswith(str(files_dir))
+
+
+def test_last_failed(populated_suite, links_dir):
+    populated_suite[-5].fail()
+    last_failed = populated_suite[-2]
+    last_failed.fail()
+    results = populated_suite.run()
+
+    fail_log = results[last_failed].get_log_path()
+    assert os.path.isfile(fail_log)
+    assert links_dir.join('last-failed').readlink() == fail_log
 
 
 @pytest.fixture
@@ -39,13 +57,42 @@ def session():
 
 
 @pytest.fixture
-def logs_dir(request, config_override, tmpdir):
-    config_override("log.root", str(tmpdir.join("logs", "files")))
+def files_dir(logs_dir):
+    return logs_dir.join("files")
+
+
+@pytest.fixture
+def links_dir(logs_dir):
+    return logs_dir.join("links")
+
+
+@pytest.fixture
+def logs_dir(request, config_override, tmpdir, relative_symlinks):
+    returned = tmpdir.join('logs')
+    config_override("log.root", str(returned.join("files")))
     config_override("log.last_session_symlink",
-                    str(tmpdir.join("logs", "links", "last-session")))
+                    str("../links/last-session" if relative_symlinks else returned.join("links", "last-session")))
     config_override("log.last_test_symlink",
-                    str(tmpdir.join("logs", "links", "last-test")))
-    return tmpdir
+                    str("../links/last-test" if relative_symlinks else returned.join("links", "last-test")))
+    config_override("log.last_failed_symlink",
+                    str("../links/last-failed" if relative_symlinks else returned.join("links", "last-failed")))
+
+    return returned
+
+
+@pytest.fixture(params=[True, False])
+def relative_symlinks(request):
+    return request.param
+
+
+@pytest.fixture
+def links_dir(logs_dir):
+    return logs_dir.join("links")
+
+
+@pytest.fixture
+def files_dir(logs_dir):
+    return logs_dir.join("files")
 
 
 _TOKEN = "logging-test"
@@ -162,7 +209,8 @@ class ExtraLoggersTest(TestCase):
         slash.log.add_log_handler(self.handler)
 
     def test(self):
-        run_tests_in_session(SampleTest, session=self.session)
+        with self.session:
+            run_tests_in_session(SampleTest, session=self.session)
         for test_result in self.session.results.iter_test_results():
             for record in self.handler.records:
                 if test_result.test_id in record.message:
