@@ -9,8 +9,6 @@ from slash.frontend import slash_run
 import requests
 import pkg_resources
 
-site_customized = False
-
 class SlashRunSiteCustomizationTest(TestCase):
     "Make sure ``slash run`` calls site.load()"
     def setUp(self):
@@ -23,28 +21,53 @@ class SlashRunSiteCustomizationTest(TestCase):
         with self.assertRaises(SystemExit):
             slash_run.slash_run([])
 
+_customization_index = 0
+_loaded_customizations = []
+
+def _apply_customization(index=0):
+    _loaded_customizations.append(index)
+
 class CustomizationTest(TestCase):
+
+    def setUp(self):
+        super(CustomizationTest, self).setUp()
+        global _loaded_customizations
+        global _customization_index
+        _customization_index = 0
+        _loaded_customizations = []
+
     def get_customization_source(self):
-        return "import {0}; {0}.site_customized=True".format(__name__)
-    def get_customization_function(self):
-        def _customize():
-            global site_customized
-            site_customized = True
-        return _customize
-    def test_customize_via_slashrc(self):
-        slashrc_path = mktemp()
-        self.forge.replace(os.path, "expanduser")
-        os.path.expanduser("~/.slash/slashrc").whenever().and_return(slashrc_path)
-        with open(slashrc_path, "w") as f:
+        global _customization_index
+        returned = "import {0}; {0}._apply_customization({1})".format(__name__, _customization_index)
+        _customization_index += 1
+        return returned
+
+    def test_customize_via_local_and_global_slashrc(self):
+        self._test_customize_via_local_slashrc(also_use_global=True)
+
+    def test_customize_via_local_slashrc(self):
+        self._test_customize_via_local_slashrc(also_use_global=False)
+
+    def _test_customize_via_local_slashrc(self, also_use_global):
+        if also_use_global:
+            global_slashrc_path = os.path.join(self.get_new_path(), "slashrc")
+            self.override_config("run.user_customization_file_path", global_slashrc_path)
+            with open(global_slashrc_path, "w") as f:
+                f.write(self.get_customization_source())
+
+        self.addCleanup(os.chdir, os.path.abspath("."))
+        os.chdir(self.get_new_path())
+        with open(".slashrc", "w") as f:
             f.write(self.get_customization_source())
-        self.forge.replay()
         self.assert_customization_loaded()
+
     def test_customize_via_env_var(self):
         os.environ["SLASH_SETTINGS"] = custom_filename = mktemp()
         self.addCleanup(os.environ.pop, "SLASH_SETTINGS")
         with open(custom_filename, "w") as f:
             f.write(self.get_customization_source())
         self.assert_customization_loaded()
+
     def test_customize_via_url(self):
         url = "http://nonexistent.com/some/path/to/custom/file.py"
         self.forge.replace(requests, "get")
@@ -56,15 +79,18 @@ class CustomizationTest(TestCase):
         self.addCleanup(os.environ.pop, "SLASH_SETTINGS")
         self.forge.replay()
         self.assert_customization_loaded()
+
     def test_customize_via_pkgutil_entry_point(self):
         self.forge.replace(pkg_resources, "iter_entry_points")
         entry_point = self.forge.create_wildcard_mock()
         pkg_resources.iter_entry_points("slash.site.customize").and_return(iter([entry_point]))
-        entry_point.load().and_return(self.get_customization_function())
+        unused = self.get_customization_source() # expect a single customization
+        entry_point.load().and_return(_apply_customization)
         self.forge.replay()
         self.assert_customization_loaded()
+
     def assert_customization_loaded(self):
-        global site_customized
-        site_customized = False
+        global _loaded_customizations
+        global _customization_index
         slash.site.load()
-        self.assertTrue(site_customized, "Customization not loaded!")
+        self.assertEquals(_loaded_customizations, list(range(_customization_index)))
