@@ -3,6 +3,7 @@ import slash
 
 from .utils import run_tests_assert_success
 
+
 @pytest.mark.parametrize('reprify', [repr, str])
 def test_str_repr(warning, reprify):
     assert 'this is a warning' in reprify(warning)
@@ -10,11 +11,14 @@ def test_str_repr(warning, reprify):
 def test_location(warning):
     assert warning.details['filename'] == __file__
 
+def test_to_dict(warning):
+    assert isinstance(warning.to_dict(), dict)
+
 @pytest.fixture
 def warning():
     class SampleTest(slash.Test):
         def test(self):
-            slash.logger.warning("this is a warning")
+            slash.logger.warning("this is a warning. Param: {0}", 1)
 
     session = run_tests_assert_success(SampleTest)
 
